@@ -186,6 +186,17 @@ try {
                             'message' => 'Created ' . count($results) . ' site backups'
                         ];
                     } else {
+                        // Check if site is in format "user/domain" (from root user selection)
+                        if (strpos($site, '/') !== false) {
+                            list($siteUser, $siteDomain) = explode('/', $site, 2);
+                            // Verify the extracted user matches the backup user or use the extracted user if root
+                            if ($isRoot) {
+                                $backupUser = $siteUser;
+                            } elseif ($siteUser !== $backupUser) {
+                                throw new Exception('Access denied to site from different user');
+                            }
+                            $site = $siteDomain;
+                        }
                         $result = $engine->createSiteBackup($backupUser, $site, $targetId);
                     }
                     break;
